==> formalms-3.1.0.zip: formalms/templates/standard/layout/home.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo Layout::lang_code(); ?>">
	<head>
	    <!--Fix funzionamento scorm su IE9-->
        <meta http-equiv="x-ua-compatible" content="IE=9"></meta>
        <!--END -->

		<title><?php echo Layout::title(); ?></title>
		<?php echo Layout::zone('meta'); ?>
		<?php echo Layout::meta(); ?>
		<link rel="shortcut icon" href="<?php echo Layout::path(); ?>images/favicon.png" type="image/png" />
		<link rel="shortcut icon" href="<?php echo Layout::path(); ?>images/favicon.ico" />
		<!-- reset and font stylesheet -->
		<?php echo Layout::resetter(); ?>
		<!-- common stylesheet -->
		<link rel="stylesheet" type="text/css" href="<?php echo Layout::path(); ?>style/base.css" />
		<link rel="stylesheet" type="text/css" href="<?php echo Layout::path(); ?>style/lms-home.css" />
		<?php echo Layout::rtl(); ?>
		<!-- specific stylesheet -->
		<?php YuiLib::load('base'); ?>
		<!-- printer stylesheet-->
		<?php echo Layout::accessibility(); ?>
		<!-- Page Head area -->
		<?php echo Layout::zone('page_head'); ?>
		<!-- Restyling -->
		<?php
        Util::get_js(Get::rel_path('base') . '../web/static/main.js', true, true);
        Util::get_css(Get::rel_path('base') . '../web/static/main.css', true, true);
        ?>
	</head>
	<body class="yui-skin-docebo yui-skin-sam">
		<!-- blind nav -->
		<?php echo Layout::zone('blind_navigation'); ?>
		<!-- header -->
		<div class="header">
			<div class="select-language">
				<?php echo Lang::t('_CHANGELANG', 'register') . ': ' . Layout::change_lang(); ?>
			</div>
			<!-- <h1 id="main_title"><a href="index.php"><?php echo Lang::t('_MAIN_TITLE', 'login'); ?></a></h1>-->
			<a href="index.php"><img class="left_logo" src="<?php echo Layout::path(); ?>images/company_logo.png" alt="Left logo" /></a>
			<div class="nofloat"></div>
			<div class="divider"></div>
		</div>
		<div class="webcontent">
			<?php echo Layout::zone('content'); ?>
		</div>
		<!-- footer -->
		<div class="footer">
			<?php echo Layout::zone('footer'); ?>
				<?php echo Layout::copyright(); ?>
		</div>
		<!-- def lang -->
		<?php echo Layout::zone('def_lang'); ?>
		<!-- scripts -->
		<?php echo Layout::zone('scripts'); ?>
		<!-- end scripts -->
		<?php echo Layout::zone('debug'); ?>
		<?php echo Layout::analytics(); ?>
	</body>
</html>

==> formalms-3.3.10.zip: formalms/templates/standard/layout/home.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo Layout::lang_code(); ?>">
	<head>
	    <!--Fix funzionamento scorm su IE9-->
        <meta http-equiv="x-ua-compatible" content="IE=9"></meta>
        <!--END -->

		<title><?php echo Layout::title(); ?></title>
		<?php echo Layout::zone('meta'); ?>
		<?php echo Layout::meta(); ?>
		<link rel="shortcut icon" href="<?php echo Layout::path(); ?>images/favicon.png" type="image/png" />
		<link rel="shortcut icon" href="<?php echo Layout::path(); ?>images/favicon.ico" />
		<!-- reset and font stylesheet -->
		<?php echo Layout::resetter(); ?>
		<!-- common stylesheet -->
		<link rel="stylesheet" type="text/css" href="<?php echo Layout::path(); ?>style/base.css" />
		<link rel="stylesheet" type="text/css" href="<?php echo Layout::path(); ?>style/lms-home.css" />
		<?php echo Layout::rtl(); ?>
		<!-- specific stylesheet -->
		<?php YuiLib::load('base'); ?>
		<!-- printer stylesheet-->
		<?php echo Layout::accessibility(); ?>
		<!-- Page Head area -->
		<?php echo Layout::zone('page_head'); ?>
		<!-- Restyling -->
		<?php
        Util::get_js(FormaLms\lib\Get::rel_path('base') . '../web/static/main.js?v=' . getTemplateVersion(getDefaultTemplate()), true, true);
        Util::get_css(FormaLms\lib\Get::rel_path('base') . '../web/static/main.css?v=' . getTemplateVersion(getDefaultTemplate()), true, true);
        ?>
	</head>
	<body class="yui-skin-docebo yui-skin-sam">
		<!-- blind nav -->
		<?php echo Layout::zone('blind_navigation'); ?>
		<!-- header -->
		<div class="header">
			<div class="select-language">
				<?php echo Lang::t('_CHANGELANG', 'register') . ': ' . Layout::change_lang(); ?>
			</div>
			<!-- <h1 id="main_title"><a href="index.php"><?php echo Lang::t('_MAIN_TITLE', 'login'); ?></a></h1>-->
			<a href="index.php"><img class="left_logo" src="<?php echo Layout::path(); ?>images/company_logo.png" alt="Left logo" /></a>
			<div class="nofloat"></div>
			<div class="divider"></div>
		</div>
		<div class="webcontent">
			<?php echo Layout::zone('content'); ?>
		</div>
		<!-- footer -->
		<div class="footer">
			<?php echo Layout::zone('footer'); ?>
				<?php echo Layout::copyright(); ?>
		</div>
		<!-- def lang -->
		<?php echo Layout::zone('def_lang'); ?>
		<!-- scripts -->
		<?php echo Layout::zone('scripts'); ?>
		<!-- end scripts -->
		<?php echo Layout::zone('debug'); ?>
		<?php echo Layout::analytics(); ?>
	</body>
</html>
